@@ -10,7 +10,7 @@ use Test::More;
 use UNIVERSAL::require;
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 use base 'Class::Accessor::Complex';
@@ -107,6 +107,8 @@ sub run_tests {
 
 __END__
 
+
+
 =head1 NAME
 
 Test::CompanionClasses::Engine - run tests defined in companion classes
@@ -120,13 +122,46 @@ Test::CompanionClasses::Engine - run tests defined in companion classes
 
 This is the core of C<Test::CompanionClasses>.
 
+Test::CompanionClasses::Engine inherits from L<Class::Accessor::Complex>.
+
+The superclass L<Class::Accessor::Complex> defines these methods and
+functions:
+
+    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
+    mk_array_accessors(), mk_boolean_accessors(),
+    mk_class_array_accessors(), mk_class_hash_accessors(),
+    mk_class_scalar_accessors(), mk_concat_accessors(),
+    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
+    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
+    mk_set_accessors(), mk_singleton()
+
+The superclass L<Class::Accessor> defines these methods and functions:
+
+    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
+    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
+    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
+    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
+    mk_wo_accessors(), mutator_name_for(), set()
+
+The superclass L<Class::Accessor::Installer> defines these methods and
+functions:
+
+    install_accessor(), subname()
+
 =head1 METHODS
 
 =over 4
 
 =item new
 
-A constructor per L<Class::Accessor::Complex>'s C<mk_new()>.
+    my $obj = Test::CompanionClasses::Engine->new;
+    my $obj = Test::CompanionClasses::Engine->new(%args);
+
+Creates and returns a new object. The constructor will accept as arguments a
+list of pairs, from component name to initial value. For each pair, the named
+component is initialized by calling the method of the same name with the given
+value. If called with a single hash reference, it is dereferenced and its
+key/value pairs are set as described before.
 
 =item run_tests
 
@@ -196,12 +231,16 @@ to run, then runs them.
 If you talk about this module in blogs, on del.icio.us or anywhere else,
 please use the C<testcompanionclasses> tag.
 
+=head1 VERSION 
+                   
+This document describes version 0.03 of L<Test::CompanionClasses::Engine>.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-test-companionclasses@rt.cpan.org>, or through the web interface at
+C<<bug-test-companionclasses@rt.cpan.org>>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -225,5 +264,6 @@ Copyright 2007 by Marcel GrE<uuml>nauer
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+
 =cut
 
